@@ -43,6 +43,7 @@ from .type_defs import (
     DescribeChannelModeratedByAppInstanceUserResponseTypeDef,
     DescribeChannelModeratorResponseTypeDef,
     DescribeChannelResponseTypeDef,
+    EmptyResponseMetadataTypeDef,
     GetChannelMembershipPreferencesResponseTypeDef,
     GetChannelMessageResponseTypeDef,
     GetChannelMessageStatusResponseTypeDef,
@@ -113,7 +114,7 @@ class ChimeSDKMessagingClient(BaseClient):
 
     def associate_channel_flow(
         self, *, ChannelArn: str, ChannelFlowArn: str, ChimeBearer: str
-    ) -> None:
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Associates a channel flow with a channel.
 
@@ -149,7 +150,7 @@ class ChimeSDKMessagingClient(BaseClient):
         *,
         CallbackId: str,
         ChannelArn: str,
-        ChannelMessage: "ChannelMessageCallbackTypeDef",
+        ChannelMessage: ChannelMessageCallbackTypeDef,
         DeleteResource: bool = ...
     ) -> ChannelFlowCallbackResponseTypeDef:
         """
@@ -169,7 +170,7 @@ class ChimeSDKMessagingClient(BaseClient):
         Mode: ChannelModeType = ...,
         Privacy: ChannelPrivacyType = ...,
         Metadata: str = ...,
-        Tags: Sequence["TagTypeDef"] = ...
+        Tags: Sequence[TagTypeDef] = ...
     ) -> CreateChannelResponseTypeDef:
         """
         Creates a channel to which you can add users and send messages.
@@ -192,10 +193,10 @@ class ChimeSDKMessagingClient(BaseClient):
         self,
         *,
         AppInstanceArn: str,
-        Processors: Sequence["ProcessorTypeDef"],
+        Processors: Sequence[ProcessorTypeDef],
         Name: str,
         ClientRequestToken: str,
-        Tags: Sequence["TagTypeDef"] = ...
+        Tags: Sequence[TagTypeDef] = ...
     ) -> CreateChannelFlowResponseTypeDef:
         """
         Creates a channel flow, a container for processors.
@@ -224,7 +225,7 @@ class ChimeSDKMessagingClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client/#create_channel_moderator)
         """
 
-    def delete_channel(self, *, ChannelArn: str, ChimeBearer: str) -> None:
+    def delete_channel(self, *, ChannelArn: str, ChimeBearer: str) -> EmptyResponseMetadataTypeDef:
         """
         Immediately makes a channel and its memberships inaccessible and marks them for
         deletion.
@@ -233,7 +234,9 @@ class ChimeSDKMessagingClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client/#delete_channel)
         """
 
-    def delete_channel_ban(self, *, ChannelArn: str, MemberArn: str, ChimeBearer: str) -> None:
+    def delete_channel_ban(
+        self, *, ChannelArn: str, MemberArn: str, ChimeBearer: str
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Removes a user from a channel's ban list.
 
@@ -241,7 +244,7 @@ class ChimeSDKMessagingClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client/#delete_channel_ban)
         """
 
-    def delete_channel_flow(self, *, ChannelFlowArn: str) -> None:
+    def delete_channel_flow(self, *, ChannelFlowArn: str) -> EmptyResponseMetadataTypeDef:
         """
         Deletes a channel flow, an irreversible process.
 
@@ -251,7 +254,7 @@ class ChimeSDKMessagingClient(BaseClient):
 
     def delete_channel_membership(
         self, *, ChannelArn: str, MemberArn: str, ChimeBearer: str
-    ) -> None:
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Removes a member from a channel.
 
@@ -259,7 +262,9 @@ class ChimeSDKMessagingClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client/#delete_channel_membership)
         """
 
-    def delete_channel_message(self, *, ChannelArn: str, MessageId: str, ChimeBearer: str) -> None:
+    def delete_channel_message(
+        self, *, ChannelArn: str, MessageId: str, ChimeBearer: str
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Deletes a channel message.
 
@@ -269,7 +274,7 @@ class ChimeSDKMessagingClient(BaseClient):
 
     def delete_channel_moderator(
         self, *, ChannelArn: str, ChannelModeratorArn: str, ChimeBearer: str
-    ) -> None:
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Deletes a channel moderator.
 
@@ -349,7 +354,7 @@ class ChimeSDKMessagingClient(BaseClient):
 
     def disassociate_channel_flow(
         self, *, ChannelArn: str, ChannelFlowArn: str, ChimeBearer: str
-    ) -> None:
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Disassociates a channel flow from all its channels.
 
@@ -544,7 +549,7 @@ class ChimeSDKMessagingClient(BaseClient):
         ChannelArn: str,
         MemberArn: str,
         ChimeBearer: str,
-        Preferences: "ChannelMembershipPreferencesTypeDef"
+        Preferences: ChannelMembershipPreferencesTypeDef
     ) -> PutChannelMembershipPreferencesResponseTypeDef:
         """
         Sets the membership preferences of an `AppInstanceUser` for the specified
@@ -574,8 +579,8 @@ class ChimeSDKMessagingClient(BaseClient):
         ClientRequestToken: str,
         ChimeBearer: str,
         Metadata: str = ...,
-        PushNotification: "PushNotificationConfigurationTypeDef" = ...,
-        MessageAttributes: Mapping[str, "MessageAttributeValueTypeDef"] = ...
+        PushNotification: PushNotificationConfigurationTypeDef = ...,
+        MessageAttributes: Mapping[str, MessageAttributeValueTypeDef] = ...
     ) -> SendChannelMessageResponseTypeDef:
         """
         Sends a message to a particular channel that the member is a part of.
@@ -584,7 +589,9 @@ class ChimeSDKMessagingClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client/#send_channel_message)
         """
 
-    def tag_resource(self, *, ResourceARN: str, Tags: Sequence["TagTypeDef"]) -> None:
+    def tag_resource(
+        self, *, ResourceARN: str, Tags: Sequence[TagTypeDef]
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Applies the specified tags to the specified Amazon Chime SDK messaging resource.
 
@@ -592,7 +599,9 @@ class ChimeSDKMessagingClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client/#tag_resource)
         """
 
-    def untag_resource(self, *, ResourceARN: str, TagKeys: Sequence[str]) -> None:
+    def untag_resource(
+        self, *, ResourceARN: str, TagKeys: Sequence[str]
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Removes the specified tags from the specified Amazon Chime SDK messaging
         resource.
@@ -618,7 +627,7 @@ class ChimeSDKMessagingClient(BaseClient):
         """
 
     def update_channel_flow(
-        self, *, ChannelFlowArn: str, Processors: Sequence["ProcessorTypeDef"], Name: str
+        self, *, ChannelFlowArn: str, Processors: Sequence[ProcessorTypeDef], Name: str
     ) -> UpdateChannelFlowResponseTypeDef:
         """
         Updates channel flow attributes.
